# Govee Local API

# Requirements

* Python >= 3.9
* Govee Local API enabled. Refer to https://app-h5.govee.com/user-manual/wlan-guide

# Installaction

From your terminal, run 

    pip install govee-local-api

or
    
    python3 -m pip install govee-local-api


